WebSkySZ — so_pysm_models v0.4.dev231

so_pysm_models:docs

- Index
- Modules

### Navigation

- « previous
- so_pysm_models v0.4.dev231 »
- WebSkySZ

# WebSkySZ

class `so_pysm_models.` `WebSkySZ`(version='0.3', sz_type='kinetic', nside=4096, map_dist=None, verbose=False)

  Bases: `pysm.models.template.Model`

  Methods Summary

  `get_emission`(self, freqs[, weights]) |
  `get_filename`(self) | Get SZ filenames for a websky version

  Methods Documentation

  `get_emission`(self, freqs:Unit("GHz"), weights=None) -> Unit("uK_RJ")
  `get_filename`(self)

    Get SZ filenames for a websky version